@@ -29,6 +29,24 @@ class CreateInterestedParties:
         else:
             return False
 
+    @classmethod
+    def check_availability_contract(self, name_contract):
+        params = {
+            "with": "contragent,type,usagetype_group",
+            "limit": 25,
+            "page": 1,
+            "search_like": name_contract,
+            "descendants": 1,
+            "kind_id_not": "5a69d5bf-0000-0000-0000-000070eeb9fa"
+        }
+        response = cr.get(url=pi.get_url_host() + '/api/red/contract/list', params=params)
+        r_json = response.json()
+        if len(r_json["data"]["list"]) > 0:
+            print('Документ ' + name_contract + ' уже существует')
+            return True
+        else:
+            return False
+
     @classmethod
     def get_contragent_id(cls, c_a):
         params = {
@@ -52,7 +70,6 @@ class CreateInterestedParties:
         r_json = response.json()
         for g_n in r_json["data"]["list"]:
             if (kind_name in g_n["name"]) and (len(kind_name) == len(g_n["name"])):
-                print('g_n["name"]=', g_n["name"])
                 kind_id = g_n["id"]
                 break
         return kind_id
@@ -88,6 +105,9 @@ class CreateInterestedParties:
             c_a = self.check_availability(name_ip=name_ip)
             response_person = self.get_contragent_id(c_a)
         for l_o_r in ip_person["documents"]:
+            if self.check_availability_contract(name_contract=pi.get_prefix()+prefix+l_o_r["contract_num"]):
+                print('name_contract=', pi.get_prefix()+prefix+l_o_r["contract_num"])
+                continue
             contragent_id = response_person.json()["data"]["item"]["id"]
             kind_id = self.document_kind_id(l_o_r["kind_name"])
             rights = ip.rights_json()
@@ -104,6 +124,6 @@ class CreateInterestedParties:
                 "comment": l_o_r["comment"]
             }
             response = cr.post(url=pi.get_url_host() + '/api/red/contract/add', data=params)
-            print('status_code=', response.status_code)
+            print('Создали документ ' + pi.get_prefix()+prefix+l_o_r["contract_num"]+response.ok)
         return response_person.json()["data"]["item"]
 
